@@ -54,19 +54,19 @@ thematicEvolution <- function(M, field = "ID", years, n = 250, minFreq = 2, size
   K <-  length(list_df)
   S <-  net <-  res <-  list()
   Y <-  NULL
-  pdf(file = NULL) ## to improve adding graph=FALSE in thematicMap
+  #pdf(file = NULL) ## to improve adding graph=FALSE in thematicMap
   for (k in 1:K) {
     Mk <-  list_df[[k]]
     Y[k] <-  paste(min(Mk$PY), "-", max(Mk$PY), sep = "", collapse = "")
     resk <- thematicMap(Mk, field = field, n = n, minfreq = minFreq, ngrams=ngrams,
                         stemming = stemming, size = size, n.labels = n.labels, 
-                        repel = repel, remove.terms = remove.terms, synonyms = synonyms, cluster=cluster)
+                        repel = repel, remove.terms = remove.terms, synonyms = synonyms, cluster=cluster, subgraphs = FALSE)
     resk$params <- resk$params %>% dplyr::filter(params!="minfreq")
     res[[k]] <-  resk
     net[[k]] <-  resk$net
   }
-  dev.off()
-  par(mfrow = c(1, (K - 1)))
+  #dev.off()
+  #par(mfrow = c(1, (K - 1)))
   if (K < 2) {
     print("Error")
     return()
@@ -142,6 +142,16 @@ thematicEvolution <- function(M, field = "ID", years, n = 250, minFreq = 2, size
     Nodes<-rbind(Nodes,left_join(subset(nodes,nodes$slice==i), res[[i]]$clusters[c("color","name")], by="name"))
   }
   ################ 
+  # Preparing data for plot
+  Nodes$id <- 0:(nrow(Nodes)-1)
+  Nodes <- Nodes %>% left_join(
+    rbind(INC[, -c(1, 2)] %>% select(CL1,sum) %>% rename(label=CL1),
+          INC[, -c(1, 2)] %>% select(CL2,sum)%>% rename(label=CL2)) %>% 
+      group_by(label) %>% reframe(sum=max(sum)), by="label"
+  )
+  Nodes <- Nodes %>% group_by(slice) %>% 
+    mutate(sum=sum/sum(sum,na.rm=T)) %>% ungroup()
+  ###############
   
   params <- list(field = field, 
                  years = years, 
